Learn R Programming

spatialTailDep (version 1.0.1)

KNMIdata: Wind speeds in the Netherlands.

Description

Daily maximal speeds of wind gusts, measured in 0.1 m/s. The data are observed at 22 inland weather stations in the Netherlands. Only the summer months are presented here (June, July, August). Also included are the Euclidian coordinates of the 22 weather stations, where a distance of 1 corresponds to 100 kilometers. For more information on this dataset, see Einmahl et al. (2014).

Arguments

format

KNMIdata$KNMI is a matrix with 563 rows and 22 columns, KNMI$coord is a matrix with 22 rows and 2 columns.

source

http://www.knmi.nl/climatology/daily_data/selection.cgi

References

Einmahl, J.H.J., Kiriliouk, A., Krajina, A. and Segers, J. (2014), "An M-estimator of spatial tail dependence". See http://arxiv.org/abs/1403.1975.

Examples

Run this code
data(KNMIdata)
locations <- KNMIdata$coord
pairIndices <- selectPairIndices(locations, maxDistance = 0.5)
Mestimator(KNMIdata$data, locations, pairIndices, k = 50, model="BR",
iterate=FALSE, covMat = FALSE)$theta

Run the code above in your browser using DataLab